#!/bin/bash

# Установите необходимые версии и архивы
MAVEN_VERSION="3.6.3"
JAVA_VERSION="17.0.13_11"
FFMPEG_VERSION="release-amd64-static"

# Укажите URL для скачивания архивов
MAVEN_URL="https://store.neuro-city.ru/downloads/luk/apache-maven-$MAVEN_VERSION-bin.tar.gz"
JAVA_URL="https://store.neuro-city.ru/downloads/luk/OpenJDK17U-jdk_arm_linux_hotspot_${JAVA_VERSION}.tar.gz"
FFMPEG_URL="https://store.neuro-city.ru/downloads/luk/ffmpeg-${FFMPEG_VERSION}.tar.xz"

# Папки назначения
MAVEN_ARCHIVE="apache-maven-$MAVEN_VERSION-bin.tar.gz"
JAVA_ARCHIVE="OpenJDK17U-jdk_arm_linux_hotspot_${JAVA_VERSION}.tar.gz"
FFMPEG_ARCHIVE="ffmpeg-${FFMPEG_VERSION}.tar.xz"

MAVEN_DIR="/opt/apache-maven-$MAVEN_VERSION"
JAVA_DIR="/opt/jdk-17"
FFMPEG_DIR="/usr/local/bin"

# Удалите старые архивы
rm -f $MAVEN_ARCHIVE $JAVA_ARCHIVE $FFMPEG_ARCHIVE

# Скачиваем архивы с помощью wget с проверкой ошибок
echo "Скачивание Maven..."
wget -q $MAVEN_URL -O $MAVEN_ARCHIVE
if [ $? -ne 0 ] || [ ! -s "$MAVEN_ARCHIVE" ]; then
    echo "Ошибка при скачивании Maven. Файл пустой или отсутствует."
    exit 1
fi

echo "Скачивание OpenJDK..."
wget -q $JAVA_URL -O $JAVA_ARCHIVE
if [ $? -ne 0 ] || [ ! -s "$JAVA_ARCHIVE" ]; then
    echo "Ошибка при скачивании OpenJDK. Файл пустой или отсутствует."
    exit 1
fi

echo "Скачивание FFmpeg..."
wget -q $FFMPEG_URL -O $FFMPEG_ARCHIVE
if [ $? -ne 0 ] || [ ! -s "$FFMPEG_ARCHIVE" ]; then
    echo "Ошибка при скачивании FFmpeg. Файл пустой или отсутствует."
    exit 1
fi

# Установите OpenJDK
echo "Установка OpenJDK..."
sudo tar -xvf $JAVA_ARCHIVE
sudo mv jdk-$JAVA_VERSION $JAVA_DIR

# Настройте переменные среды для Java
echo "export JAVA_HOME=$JAVA_DIR" | sudo tee /etc/profile.d/jdk.sh
echo 'export PATH=$JAVA_HOME/bin:$PATH' | sudo tee -a /etc/profile.d/jdk.sh
source /etc/profile.d/jdk.sh
java -version && echo "Java установлена" || echo "Ошибка при установке Java"

# Установите Maven
echo "Установка Maven..."
sudo tar xf $MAVEN_ARCHIVE -C /opt
sudo ln -s "$MAVEN_DIR/bin/mvn" /usr/bin/mvn
mvn -v && echo "Maven установлен" || echo "Ошибка при установке Maven"

# Установите FFmpeg
echo "Установка FFmpeg..."
sudo tar -xvf $FFMPEG_ARCHIVE
sudo cp ffmpeg-*-amd64-static/ffmpeg $FFMPEG_DIR
sudo cp ffmpeg-*-amd64-static/ffprobe $FFMPEG_DIR
ffmpeg -version && echo "FFmpeg установлен" || echo "Ошибка при установке FFmpeg"

echo "Все компоненты установлены успешно!"
